PulseTicks

Struct PulseTicks 

pub struct PulseTicks(/* private fields */);
Number of ticks, restricting the range to 0 to 32,767.

Implementations

Source

impl PulseTicks

pub const fn zero() -> Self

Use zero ticks.

pub const fn max() -> Self

Use the maximum value of 32767.

pub const fn new(ticks: u16) -> Result<Self, EspError>

Create a PulseTicks from the given number of ticks.

Errors

If the given number of ticks is larger than PulseTicks::max(), an error with the code ESP_ERR_INVALID_ARG will be returned.

pub const fn new_with_duration( resolution: Hertz, duration: Duration, ) -> Result<Self, EspError>

Constructs a PulseTicks from a [Duration].

Errors

If the duration is too long to be represented as ticks with the given resolution, an error with the code [ERR_EOVERFLOW] or ESP_ERR_INVALID_ARG will be returned.

pub const fn ticks(&self) -> u16

Returns the number of ticks.

pub const fn duration(&self, resolution: Hertz) -> Duration

Returns the duration it takes for the number of ticks, depending on the given clock ticks.

Panics

This function panics if the conversion from ticks to duration overflows.