RxDoneEventData

Struct RxDoneEventData 

#[non_exhaustive]
pub struct RxDoneEventData { pub received_symbols: *mut Symbol, pub num_symbols: usize, pub is_last: bool, }
Type of RMT RX done event data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
received_symbols: *mut Symbol

Pointer to the received RMT symbols.

These symbols are saved in the internal buffer of the RxChannelDriver. You are not allowed to free this buffer.

If the partial receive feature is enabled, then the buffer will be used as a “second level buffer”, where its content can be overwritten by data coming in afterwards. In this case, you should copy the received data to another place if you want to keep it or process it later.

num_symbols: usize

The number of received RMT symbols.

This value will never be larger than the buffer size of the buffer passed to the receive function.

If the buffer is not sufficient to accomodate all the received RMT symbols, the driver only keeps the maximum number of symbols that the buffer can hold, and excess symbols are discarded or ignored.

is_last: bool

Indicates whether the current received data is the last part of the transaction.

This is useful for when ReceiveConfig::enable_partial_rx is enabled, and the data is received in parts.

For receives where partial rx is not enabled, this field will always be true.

Implementations

Source

impl RxDoneEventData

pub unsafe fn as_slice(&self) -> &[Symbol]

Returns the received symbols as a slice.

Safety

Both the pointer and the length must be valid. If these haven’t been changed from the values provided by the driver, this should be the case in the ISR callback.