TxDoneEventData

Struct TxDoneEventData 

#[non_exhaustive]
pub struct TxDoneEventData { pub num_symbols: usize, }
Type of RMT TX done event data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
num_symbols: usize

The number of symbols (Symbol) that have been transmitted.

This also reflects the size of the encoding artifacts. Please note, this value accounts for the EOF symbol as well, which is automatically appended by the driver to mark the end of one transaction.