pub struct PulseTicks(/* private fields */);Expand description
Number of ticks, restricting the range to 0 to 32,767.
Implementations
Sourceimpl PulseTicks
impl PulseTicks
Sourcepub const fn new(ticks: u16) -> Result<Self, EspError>
pub const fn new(ticks: u16) -> Result<Self, EspError>
Create a PulseTicks from the given number of ticks.
Errors
If the given number of ticks is larger than PulseTicks::max(), an error with the code
ESP_ERR_INVALID_ARG will be returned.
Sourcepub const fn new_with_duration(
resolution: Hertz,
duration: Duration,
) -> Result<Self, EspError>
pub const fn new_with_duration( resolution: Hertz, duration: Duration, ) -> Result<Self, EspError>
Constructs a PulseTicks from a [Duration].
Errors
If the duration is too long to be represented as ticks with the given resolution,
an error with the code [ERR_EOVERFLOW] or ESP_ERR_INVALID_ARG will be returned.