#[non_exhaustive]pub struct RxDoneEventData {
pub received_symbols: *mut Symbol,
pub num_symbols: usize,
pub is_last: bool,
}Expand description
Type of RMT RX done event data.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.received_symbols: *mut SymbolPointer to the received RMT symbols.
These symbols are saved in the internal buffer of the RxChannelDriver.
You are not allowed to free this buffer.
If the partial receive feature is enabled, then the buffer will be used as a “second level buffer”, where its content can be overwritten by data coming in afterwards. In this case, you should copy the received data to another place if you want to keep it or process it later.
num_symbols: usizeThe number of received RMT symbols.
This value will never be larger than the buffer size of the buffer passed to the receive function.
If the buffer is not sufficient to accomodate all the received RMT symbols, the driver only keeps the maximum number of symbols that the buffer can hold, and excess symbols are discarded or ignored.
is_last: boolIndicates whether the current received data is the last part of the transaction.
This is useful for when ReceiveConfig::enable_partial_rx is enabled,
and the data is received in parts.
For receives where partial rx is not enabled, this field will always be true.
Implementations